You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@shiro.apache.org by ad...@apache.org on 2009/06/18 05:13:47 UTC

svn commit: r785881 [7/11] - in /incubator/shiro/trunk: ./ all/ core/src/main/java/org/apache/ki/ core/src/main/java/org/apache/shiro/ core/src/main/java/org/apache/shiro/aop/ core/src/main/java/org/apache/shiro/authc/ core/src/main/java/org/apache/shi...

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/UnknownAccountExceptionTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/UnknownAccountExceptionTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/UnknownAccountExceptionTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/UnknownAccountExceptionTest.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc;
+package org.apache.shiro.authc;
 
-import org.apache.ki.ExceptionTest;
+import org.apache.shiro.ExceptionTest;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/AllowAllCredentialsMatcherTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/AllowAllCredentialsMatcherTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/AllowAllCredentialsMatcherTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/AllowAllCredentialsMatcherTest.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
 import static org.junit.Assert.assertTrue;
 import org.junit.Test;

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/HashedCredentialsMatcherTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/HashedCredentialsMatcherTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/HashedCredentialsMatcherTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/HashedCredentialsMatcherTest.java Thu Jun 18 03:13:34 2009
@@ -16,17 +16,17 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
 import junit.framework.TestCase;
 import org.junit.Test;
 
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.SimpleAuthenticationInfo;
-import org.apache.ki.authc.UsernamePasswordToken;
-import org.apache.ki.crypto.hash.AbstractHash;
-import org.apache.ki.util.ClassUtils;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.SimpleAuthenticationInfo;
+import org.apache.shiro.authc.UsernamePasswordToken;
+import org.apache.shiro.crypto.hash.AbstractHash;
+import org.apache.shiro.util.ClassUtils;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Md2CredentialsMatcherTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Md2CredentialsMatcherTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Md2CredentialsMatcherTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Md2CredentialsMatcherTest.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
-import org.apache.ki.crypto.hash.AbstractHash;
-import org.apache.ki.crypto.hash.Md2Hash;
+import org.apache.shiro.crypto.hash.AbstractHash;
+import org.apache.shiro.crypto.hash.Md2Hash;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Md5CredentialsMatcherTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Md5CredentialsMatcherTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Md5CredentialsMatcherTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Md5CredentialsMatcherTest.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
-import org.apache.ki.crypto.hash.AbstractHash;
-import org.apache.ki.crypto.hash.Md5Hash;
+import org.apache.shiro.crypto.hash.AbstractHash;
+import org.apache.shiro.crypto.hash.Md5Hash;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Sha1CredentialsMatcherTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Sha1CredentialsMatcherTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Sha1CredentialsMatcherTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Sha1CredentialsMatcherTest.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
-import org.apache.ki.crypto.hash.AbstractHash;
-import org.apache.ki.crypto.hash.Sha1Hash;
+import org.apache.shiro.crypto.hash.AbstractHash;
+import org.apache.shiro.crypto.hash.Sha1Hash;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Sha256CredentialsMatcherTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Sha256CredentialsMatcherTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Sha256CredentialsMatcherTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Sha256CredentialsMatcherTest.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
-import org.apache.ki.crypto.hash.AbstractHash;
-import org.apache.ki.crypto.hash.Sha256Hash;
+import org.apache.shiro.crypto.hash.AbstractHash;
+import org.apache.shiro.crypto.hash.Sha256Hash;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Sha384CredentialsMatcherTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Sha384CredentialsMatcherTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Sha384CredentialsMatcherTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Sha384CredentialsMatcherTest.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
-import org.apache.ki.crypto.hash.AbstractHash;
-import org.apache.ki.crypto.hash.Sha384Hash;
+import org.apache.shiro.crypto.hash.AbstractHash;
+import org.apache.shiro.crypto.hash.Sha384Hash;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Sha512CredentialsMatcherTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Sha512CredentialsMatcherTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Sha512CredentialsMatcherTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/credential/Sha512CredentialsMatcherTest.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
-import org.apache.ki.crypto.hash.AbstractHash;
-import org.apache.ki.crypto.hash.Sha512Hash;
+import org.apache.shiro.crypto.hash.AbstractHash;
+import org.apache.shiro.crypto.hash.Sha512Hash;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/pam/AllSuccessfulStrategyTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/pam/AllSuccessfulStrategyTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/pam/AllSuccessfulStrategyTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/pam/AllSuccessfulStrategyTest.java Thu Jun 18 03:13:34 2009
@@ -16,20 +16,20 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.pam;
+package org.apache.shiro.authc.pam;
 
 import static org.junit.Assert.assertNotNull;
 import org.junit.Before;
 import org.junit.Test;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authz.AuthorizationInfo;
-import org.apache.ki.realm.AuthorizingRealm;
-import org.apache.ki.realm.Realm;
-import org.apache.ki.realm.SimpleAccountRealm;
-import org.apache.ki.subject.PrincipalCollection;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authz.AuthorizationInfo;
+import org.apache.shiro.realm.AuthorizingRealm;
+import org.apache.shiro.realm.Realm;
+import org.apache.shiro.realm.SimpleAccountRealm;
+import org.apache.shiro.subject.PrincipalCollection;
 
 
 public class AllSuccessfulStrategyTest {

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/support/AbstractAuthenticatorTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/support/AbstractAuthenticatorTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/support/AbstractAuthenticatorTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/support/AbstractAuthenticatorTest.java Thu Jun 18 03:13:34 2009
@@ -16,20 +16,20 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.support;
+package org.apache.shiro.authc.support;
 
 import static org.easymock.EasyMock.*;
 import static org.junit.Assert.*;
 import org.junit.Before;
 import org.junit.Test;
 
-import org.apache.ki.authc.AbstractAuthenticator;
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationListener;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.SimpleAuthenticationInfo;
-import org.apache.ki.authc.UsernamePasswordToken;
+import org.apache.shiro.authc.AbstractAuthenticator;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationListener;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.SimpleAuthenticationInfo;
+import org.apache.shiro.authc.UsernamePasswordToken;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/AuthorizationExceptionTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/AuthorizationExceptionTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/AuthorizationExceptionTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/AuthorizationExceptionTest.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
 
-import org.apache.ki.ExceptionTest;
+import org.apache.shiro.ExceptionTest;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/HostUnauthorizedExceptionTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/HostUnauthorizedExceptionTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/HostUnauthorizedExceptionTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/HostUnauthorizedExceptionTest.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
 
-import org.apache.ki.ExceptionTest;
+import org.apache.shiro.ExceptionTest;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/UnauthenticatedExceptionTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/UnauthenticatedExceptionTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/UnauthenticatedExceptionTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/UnauthenticatedExceptionTest.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
 
-import org.apache.ki.ExceptionTest;
+import org.apache.shiro.ExceptionTest;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/UnauthorizedExceptionTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/UnauthorizedExceptionTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/UnauthorizedExceptionTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/UnauthorizedExceptionTest.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
 
-import org.apache.ki.ExceptionTest;
+import org.apache.shiro.ExceptionTest;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/permission/AllPermissionTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/permission/AllPermissionTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/permission/AllPermissionTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/permission/AllPermissionTest.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.permission;
+package org.apache.shiro.authz.permission;
 
 import static org.junit.Assert.assertTrue;
 import org.junit.Test;

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/permission/WildcardPermissionTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/permission/WildcardPermissionTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/permission/WildcardPermissionTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authz/permission/WildcardPermissionTest.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.permission;
+package org.apache.shiro.authz.permission;
 
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/config/CompositeBean.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/config/CompositeBean.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/config/CompositeBean.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/config/CompositeBean.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.config;
+package org.apache.shiro.config;
 
 /**
  * @author Les Hazlewood

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/config/ReflectionBuilderTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/config/ReflectionBuilderTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/config/ReflectionBuilderTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/config/ReflectionBuilderTest.java Thu Jun 18 03:13:34 2009
@@ -16,16 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.config;
+package org.apache.shiro.config;
 
 import java.util.LinkedHashMap;
 import java.util.Map;
 
 import static org.junit.Assert.*;
 import org.junit.Test;
-import org.apache.ki.config.ConfigurationException;
-import org.apache.ki.config.ReflectionBuilder;
-import org.apache.ki.config.UnresolveableReferenceException;
+import org.apache.shiro.config.ConfigurationException;
+import org.apache.shiro.config.ReflectionBuilder;
+import org.apache.shiro.config.UnresolveableReferenceException;
 
 /**
  * @author Les Hazlewood
@@ -36,7 +36,7 @@
     @Test
     public void testSimpleConfig() {
         Map<String, String> defs = new LinkedHashMap<String, String>();
-        defs.put("compositeBean", "org.apache.ki.config.CompositeBean");
+        defs.put("compositeBean", "org.apache.shiro.config.CompositeBean");
         defs.put("compositeBean.stringProp", "blah");
         defs.put("compositeBean.booleanProp", "true");
         defs.put("compositeBean.intProp", "42");
@@ -54,7 +54,7 @@
     @Test
     public void testSimpleConfigWithDollarSignStringValue() {
         Map<String, String> defs = new LinkedHashMap<String, String>();
-        defs.put("compositeBean", "org.apache.ki.config.CompositeBean");
+        defs.put("compositeBean", "org.apache.shiro.config.CompositeBean");
         defs.put("compositeBean.stringProp", "\\$500");
 
         ReflectionBuilder builder = new ReflectionBuilder();
@@ -67,9 +67,9 @@
     @Test
     public void testObjectReferenceConfig() {
         Map<String, String> defs = new LinkedHashMap<String, String>();
-        defs.put("simpleBean", "org.apache.ki.config.SimpleBean");
+        defs.put("simpleBean", "org.apache.shiro.config.SimpleBean");
         defs.put("simpleBean.intProp", "101");
-        defs.put("compositeBean", "org.apache.ki.config.CompositeBean");
+        defs.put("compositeBean", "org.apache.shiro.config.CompositeBean");
         defs.put("compositeBean.stringProp", "blah");
         defs.put("compositeBean.simpleBean", "$simpleBean");
 
@@ -89,8 +89,8 @@
     @Test(expected = ConfigurationException.class)
     public void testObjectReferenceConfigWithTypeMismatch() {
         Map<String, String> defs = new LinkedHashMap<String, String>();
-        defs.put("simpleBean", "org.apache.ki.config.SimpleBean");
-        defs.put("compositeBean", "org.apache.ki.config.CompositeBean");
+        defs.put("simpleBean", "org.apache.shiro.config.SimpleBean");
+        defs.put("compositeBean", "org.apache.shiro.config.CompositeBean");
         defs.put("compositeBean.simpleBean", "simpleBean");
         ReflectionBuilder builder = new ReflectionBuilder();
         builder.buildObjects(defs);
@@ -99,8 +99,8 @@
     @Test(expected = UnresolveableReferenceException.class)
     public void testObjectReferenceConfigWithInvalidReference() {
         Map<String, String> defs = new LinkedHashMap<String, String>();
-        defs.put("simpleBean", "org.apache.ki.config.SimpleBean");
-        defs.put("compositeBean", "org.apache.ki.config.CompositeBean");
+        defs.put("simpleBean", "org.apache.shiro.config.SimpleBean");
+        defs.put("compositeBean", "org.apache.shiro.config.CompositeBean");
         defs.put("compositeBean.simpleBean", "$foo");
         ReflectionBuilder builder = new ReflectionBuilder();
         builder.buildObjects(defs);

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/config/SimpleBean.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/config/SimpleBean.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/config/SimpleBean.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/config/SimpleBean.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.config;
+package org.apache.shiro.config;
 
 /**
  * @author Les Hazlewood

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/io/ResourceExceptionTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/io/ResourceExceptionTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/io/ResourceExceptionTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/io/ResourceExceptionTest.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.io;
+package org.apache.shiro.io;
 
-import org.apache.ki.ExceptionTest;
+import org.apache.shiro.ExceptionTest;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/io/SerializationExceptionTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/io/SerializationExceptionTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/io/SerializationExceptionTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/io/SerializationExceptionTest.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.io;
+package org.apache.shiro.io;
 
-import org.apache.ki.ExceptionTest;
+import org.apache.shiro.ExceptionTest;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/mgt/DefaultSecurityManagerTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/mgt/DefaultSecurityManagerTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/mgt/DefaultSecurityManagerTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/mgt/DefaultSecurityManagerTest.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
 import java.io.Serializable;
 
@@ -25,14 +25,14 @@
 import org.junit.Before;
 import org.junit.Test;
 
-import org.apache.ki.SecurityUtils;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.UsernamePasswordToken;
-import org.apache.ki.realm.text.PropertiesRealm;
-import org.apache.ki.session.Session;
-import org.apache.ki.session.mgt.AbstractValidatingSessionManager;
-import org.apache.ki.subject.Subject;
-import org.apache.ki.util.ThreadContext;
+import org.apache.shiro.SecurityUtils;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.UsernamePasswordToken;
+import org.apache.shiro.realm.text.PropertiesRealm;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.session.mgt.AbstractValidatingSessionManager;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.util.ThreadContext;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/mgt/VMSingletonDefaultSecurityManagerTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/mgt/VMSingletonDefaultSecurityManagerTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/mgt/VMSingletonDefaultSecurityManagerTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/mgt/VMSingletonDefaultSecurityManagerTest.java Thu Jun 18 03:13:34 2009
@@ -16,19 +16,19 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
 import org.junit.After;
 import static org.junit.Assert.assertTrue;
 import org.junit.Before;
 import org.junit.Test;
 
-import org.apache.ki.SecurityUtils;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.UsernamePasswordToken;
-import org.apache.ki.realm.text.PropertiesRealm;
-import org.apache.ki.subject.Subject;
-import org.apache.ki.util.ThreadContext;
+import org.apache.shiro.SecurityUtils;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.UsernamePasswordToken;
+import org.apache.shiro.realm.text.PropertiesRealm;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.util.ThreadContext;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/realm/AuthorizingRealmTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/realm/AuthorizingRealmTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/realm/AuthorizingRealmTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/realm/AuthorizingRealmTest.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm;
+package org.apache.shiro.realm;
 
 import java.net.InetAddress;
 import java.net.UnknownHostException;
@@ -32,23 +32,23 @@
 import org.junit.Before;
 import org.junit.Test;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.SimpleAccount;
-import org.apache.ki.authc.SimpleAuthenticationInfo;
-import org.apache.ki.authc.UsernamePasswordToken;
-import org.apache.ki.authc.credential.AllowAllCredentialsMatcher;
-import org.apache.ki.authc.credential.CredentialsMatcher;
-import org.apache.ki.authz.AuthorizationInfo;
-import org.apache.ki.authz.Permission;
-import org.apache.ki.authz.SimpleAuthorizationInfo;
-import org.apache.ki.authz.UnauthorizedException;
-import org.apache.ki.authz.permission.WildcardPermission;
-import org.apache.ki.mgt.DefaultSecurityManager;
-import org.apache.ki.subject.PrincipalCollection;
-import org.apache.ki.subject.SimplePrincipalCollection;
-import org.apache.ki.subject.Subject;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.SimpleAccount;
+import org.apache.shiro.authc.SimpleAuthenticationInfo;
+import org.apache.shiro.authc.UsernamePasswordToken;
+import org.apache.shiro.authc.credential.AllowAllCredentialsMatcher;
+import org.apache.shiro.authc.credential.CredentialsMatcher;
+import org.apache.shiro.authz.AuthorizationInfo;
+import org.apache.shiro.authz.Permission;
+import org.apache.shiro.authz.SimpleAuthorizationInfo;
+import org.apache.shiro.authz.UnauthorizedException;
+import org.apache.shiro.authz.permission.WildcardPermission;
+import org.apache.shiro.mgt.DefaultSecurityManager;
+import org.apache.shiro.subject.PrincipalCollection;
+import org.apache.shiro.subject.SimplePrincipalCollection;
+import org.apache.shiro.subject.Subject;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/realm/UserIdPrincipal.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/realm/UserIdPrincipal.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/realm/UserIdPrincipal.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/realm/UserIdPrincipal.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm;
+package org.apache.shiro.realm;
 
 import java.io.Serializable;
 import java.security.Principal;

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/realm/UsernamePrincipal.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/realm/UsernamePrincipal.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/realm/UsernamePrincipal.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/realm/UsernamePrincipal.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm;
+package org.apache.shiro.realm;
 
 import java.io.Serializable;
 import java.security.Principal;

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/realm/activedirectory/ActiveDirectoryRealmTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/realm/activedirectory/ActiveDirectoryRealmTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/realm/activedirectory/ActiveDirectoryRealmTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/realm/activedirectory/ActiveDirectoryRealmTest.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.realm.activedirectory;
+package org.apache.shiro.realm.activedirectory;
 
 import java.net.InetAddress;
 import java.net.UnknownHostException;
@@ -29,24 +29,24 @@
 import org.junit.Before;
 import org.junit.Test;
 
-import org.apache.ki.SecurityUtils;
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.SimpleAccount;
-import org.apache.ki.authc.UsernamePasswordToken;
-import org.apache.ki.authc.credential.CredentialsMatcher;
-import org.apache.ki.authz.AuthorizationInfo;
-import org.apache.ki.authz.SimpleAuthorizationInfo;
-import org.apache.ki.mgt.DefaultSecurityManager;
-import org.apache.ki.realm.AuthorizingRealm;
-import org.apache.ki.realm.UserIdPrincipal;
-import org.apache.ki.realm.UsernamePrincipal;
-import org.apache.ki.realm.ldap.LdapContextFactory;
-import org.apache.ki.subject.PrincipalCollection;
-import org.apache.ki.subject.SimplePrincipalCollection;
-import org.apache.ki.subject.Subject;
-import org.apache.ki.util.ThreadContext;
+import org.apache.shiro.SecurityUtils;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.SimpleAccount;
+import org.apache.shiro.authc.UsernamePasswordToken;
+import org.apache.shiro.authc.credential.CredentialsMatcher;
+import org.apache.shiro.authz.AuthorizationInfo;
+import org.apache.shiro.authz.SimpleAuthorizationInfo;
+import org.apache.shiro.mgt.DefaultSecurityManager;
+import org.apache.shiro.realm.AuthorizingRealm;
+import org.apache.shiro.realm.UserIdPrincipal;
+import org.apache.shiro.realm.UsernamePrincipal;
+import org.apache.shiro.realm.ldap.LdapContextFactory;
+import org.apache.shiro.subject.PrincipalCollection;
+import org.apache.shiro.subject.SimplePrincipalCollection;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.util.ThreadContext;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/subject/DelegatingSubjectTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/subject/DelegatingSubjectTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/subject/DelegatingSubjectTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/subject/DelegatingSubjectTest.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.subject;
+package org.apache.shiro.subject;
 
 import java.io.Serializable;
 
@@ -25,9 +25,9 @@
 import org.junit.Before;
 import org.junit.Test;
 
-import org.apache.ki.mgt.DefaultSecurityManager;
-import org.apache.ki.session.Session;
-import org.apache.ki.util.ThreadContext;
+import org.apache.shiro.mgt.DefaultSecurityManager;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.util.ThreadContext;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/util/RegExPatternMatcherTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/util/RegExPatternMatcherTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/util/RegExPatternMatcherTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/util/RegExPatternMatcherTest.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
 import org.junit.Test;
 import static org.junit.Assert.*;

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/util/StringUtilsTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/util/StringUtilsTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/util/StringUtilsTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/util/StringUtilsTest.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
 import static org.junit.Assert.*;
 import org.junit.Test;

Modified: incubator/shiro/trunk/core/src/test/resources/log4j.properties
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/resources/log4j.properties?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/resources/log4j.properties (original)
+++ incubator/shiro/trunk/core/src/test/resources/log4j.properties Thu Jun 18 03:13:34 2009
@@ -34,4 +34,4 @@
 
 log4j.logger.net.sf.ehcache=WARN
 
-log4j.logger.org.apache.ki.util.ThreadContext=WARN
\ No newline at end of file
+log4j.logger.org.apache.shiro.util.ThreadContext=WARN
\ No newline at end of file

Modified: incubator/shiro/trunk/pom.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/pom.xml?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/pom.xml (original)
+++ incubator/shiro/trunk/pom.xml Thu Jun 18 03:13:34 2009
@@ -52,7 +52,7 @@
 
     <issueManagement>
         <system>Jira</system>
-        <url>http://issues.apache.org/jira/browse/KI</url>
+        <url>http://issues.apache.org/jira/browse/SHIRO</url>
     </issueManagement>
     <ciManagement>
         <system>Hudson</system>

Modified: incubator/shiro/trunk/samples/quickstart/src/main/java/Quickstart.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/quickstart/src/main/java/Quickstart.java?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/quickstart/src/main/resources/log4j.properties (original)
+++ incubator/shiro/trunk/samples/quickstart/src/main/resources/log4j.properties Thu Jun 18 03:13:34 2009
@@ -28,9 +28,9 @@
 # Spring
 log4j.logger.org.springframework=WARN
 
-# Default Ki logging
-log4j.logger.org.ki=TRACE
+# Default Shiro logging
+log4j.logger.org.apache.shiro=TRACE
 
 # Disable verbose logging
-log4j.logger.org.apache.ki.util.ThreadContext=WARN
-log4j.logger.org.apache.ki.cache.ehcache.EhCache=WARN
+log4j.logger.org.apache.shiro.util.ThreadContext=WARN
+log4j.logger.org.apache.shiro.cache.ehcache.EhCache=WARN

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/dao/BootstrapDataPopulator.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/dao/BootstrapDataPopulator.java?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/dao/BootstrapDataPopulator.java (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/dao/BootstrapDataPopulator.java Thu Jun 18 03:13:34 2009
@@ -19,7 +19,7 @@
 package org.jsecurity.samples.sprhib.dao;
 
 import org.hibernate.SessionFactory;
-import org.apache.ki.crypto.hash.Sha256Hash;
+import org.apache.shiro.crypto.hash.Sha256Hash;
 import org.springframework.beans.factory.InitializingBean;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.jdbc.core.JdbcTemplate;
@@ -55,7 +55,7 @@
         jdbcTemplate.execute( "insert into roles values (1, 'user', 'The default role given to all users.')" );
         jdbcTemplate.execute( "insert into roles values (2, 'admin', 'The administrator role only given to site admins')" );
         jdbcTemplate.execute( "insert into roles_permissions values (2, 'user:*')" );
-        jdbcTemplate.execute( "insert into users(id,username,email,password) values (1, 'admin', 'sample@ki.apache.org', '" + new Sha256Hash("admin").toHex() + "')" );
+        jdbcTemplate.execute( "insert into users(id,username,email,password) values (1, 'admin', 'sample@shiro.apache.org', '" + new Sha256Hash("admin").toHex() + "')" );
         jdbcTemplate.execute( "insert into users_roles values (1, 2)" );
         
 

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/security/SampleRealm.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/security/SampleRealm.java?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/service/DefaultUserService.java (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/service/DefaultUserService.java Thu Jun 18 03:13:34 2009
@@ -18,8 +18,8 @@
  */
 package org.jsecurity.samples.sprhib.service;
 
-import org.apache.ki.SecurityUtils;
-import org.apache.ki.crypto.hash.Sha256Hash;
+import org.apache.shiro.SecurityUtils;
+import org.apache.shiro.crypto.hash.Sha256Hash;
 import org.jsecurity.samples.sprhib.dao.UserDAO;
 import org.jsecurity.samples.sprhib.model.User;
 import org.springframework.beans.factory.annotation.Autowired;

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/EditUserCommand.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/EditUserCommand.java?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/EditUserCommand.java (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/EditUserCommand.java Thu Jun 18 03:13:34 2009
@@ -18,7 +18,7 @@
  */
 package org.jsecurity.samples.sprhib.web;
 
-import org.apache.ki.crypto.hash.Sha256Hash;
+import org.apache.shiro.crypto.hash.Sha256Hash;
 import org.jsecurity.samples.sprhib.model.User;
 import org.springframework.util.Assert;
 import org.springframework.util.StringUtils;

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/EditUserValidator.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/EditUserValidator.java?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/EditUserValidator.java (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/EditUserValidator.java Thu Jun 18 03:13:34 2009
@@ -18,7 +18,7 @@
  */
 package org.jsecurity.samples.sprhib.web;
 
-import org.apache.ki.util.StringUtils;
+import org.apache.shiro.util.StringUtils;
 import org.springframework.validation.Errors;
 import org.springframework.validation.ValidationUtils;
 import org.springframework.validation.Validator;

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/ManageUsersController.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/ManageUsersController.java?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/ManageUsersController.java (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/ManageUsersController.java Thu Jun 18 03:13:34 2009
@@ -18,7 +18,7 @@
  */
 package org.jsecurity.samples.sprhib.web;
 
-import org.apache.ki.authz.annotation.RequiresPermissions;
+import org.apache.shiro.authz.annotation.RequiresPermissions;
 import org.jsecurity.samples.sprhib.model.User;
 import org.jsecurity.samples.sprhib.service.UserService;
 import org.springframework.beans.factory.annotation.Autowired;

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/SecurityController.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/SecurityController.java?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/SecurityController.java (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/SecurityController.java Thu Jun 18 03:13:34 2009
@@ -18,9 +18,9 @@
  */
 package org.jsecurity.samples.sprhib.web;
 
-import org.apache.ki.SecurityUtils;
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.UsernamePasswordToken;
+import org.apache.shiro.SecurityUtils;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.UsernamePasswordToken;
 import org.springframework.stereotype.Controller;
 import org.springframework.ui.Model;
 import org.springframework.validation.BindingResult;

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/SignupController.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/SignupController.java?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/SignupController.java (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/SignupController.java Thu Jun 18 03:13:34 2009
@@ -18,8 +18,8 @@
  */
 package org.jsecurity.samples.sprhib.web;
 
-import org.apache.ki.SecurityUtils;
-import org.apache.ki.authc.UsernamePasswordToken;
+import org.apache.shiro.SecurityUtils;
+import org.apache.shiro.authc.UsernamePasswordToken;
 import org.jsecurity.samples.sprhib.service.UserService;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Controller;

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/SignupValidator.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/SignupValidator.java?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/SignupValidator.java (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/web/SignupValidator.java Thu Jun 18 03:13:34 2009
@@ -18,7 +18,7 @@
  */
 package org.jsecurity.samples.sprhib.web;
 
-import org.apache.ki.util.StringUtils;
+import org.apache.shiro.util.StringUtils;
 import org.springframework.validation.Errors;
 import org.springframework.validation.ValidationUtils;
 import org.springframework.validation.Validator;

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/resources/ehcache.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/resources/ehcache.xml?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/resources/ehcache.xml (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/resources/ehcache.xml Thu Jun 18 03:13:34 2009
@@ -18,7 +18,7 @@
   -->
 <ehcache>
 
-    <diskStore path="java.io.tmpdir/ki-spring-hibernate-ehcache"/>
+    <diskStore path="java.io.tmpdir/shiro-spring-hibernate-ehcache"/>
 
 
     <defaultCache
@@ -33,22 +33,22 @@
         Hibernate Object Caches
         =================================================================-->
 
-    <cache name="org.ki.samples.sprhib.model.Role"
+    <cache name="org.shiro.samples.sprhib.model.Role"
         maxElementsInMemory="100"
         timeToLiveSeconds="0"
         overflowToDisk="true"/>
 
-    <cache name="org.ki.samples.sprhib.model.Role.permissions"
+    <cache name="org.shiro.samples.sprhib.model.Role.permissions"
         maxElementsInMemory="100"
         timeToLiveSeconds="0"
         overflowToDisk="true"/>
 
-    <cache name="org.ki.samples.sprhib.model.User"
+    <cache name="org.shiro.samples.sprhib.model.User"
         maxElementsInMemory="1000"
         timeToLiveSeconds="3600"
         overflowToDisk="true"/>
 
-    <cache name="org.ki.samples.sprhib.model.User.roles"
+    <cache name="org.shiro.samples.sprhib.model.User.roles"
         maxElementsInMemory="1000"
         timeToLiveSeconds="3600"
         overflowToDisk="true"/>

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/resources/hibernate.cfg.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/resources/hibernate.cfg.xml?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/resources/hibernate.cfg.xml (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/resources/hibernate.cfg.xml Thu Jun 18 03:13:34 2009
@@ -28,8 +28,8 @@
     <!-- DB schema will be updated if needed -->
     <property name="hbm2ddl.auto">update</property>
 
-    <mapping class="org.ki.samples.sprhib.model.Role"/>
-    <mapping class="org.ki.samples.sprhib.model.User"/>
+    <mapping class="org.shiro.samples.sprhib.model.Role"/>
+    <mapping class="org.shiro.samples.sprhib.model.User"/>
 
   </session-factory>
 </hibernate-configuration>
\ No newline at end of file

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/resources/log4j.properties
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/resources/log4j.properties?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/resources/log4j.properties (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/resources/log4j.properties Thu Jun 18 03:13:34 2009
@@ -31,9 +31,9 @@
 # Hibernate
 log4j.logger.org.hibernate=WARN
 
-# Default Ki logging
-log4j.logger.org.ki=TRACE
+# Default Shiro logging
+log4j.logger.org.shiro=TRACE
 
 # Disable verbose logging
-log4j.logger.org.apache.ki.util.ThreadContext=WARN
-log4j.logger.org.apache.ki.cache.ehcache.EhCache=WARN
+log4j.logger.org.apache.shiro.util.ThreadContext=WARN
+log4j.logger.org.apache.shiro.cache.ehcache.EhCache=WARN

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/applicationContext.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/applicationContext.xml?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/applicationContext.xml (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/applicationContext.xml Thu Jun 18 03:13:34 2009
@@ -32,11 +32,11 @@
     <context:annotation-config/>
 
     <!-- Scan sample packages for Spring annotations -->
-    <context:component-scan base-package="org.ki.samples.sprhib.dao"/>
-    <context:component-scan base-package="org.ki.samples.sprhib.security"/>
-    <context:component-scan base-package="org.ki.samples.sprhib.service"/>
+    <context:component-scan base-package="org.shiro.samples.sprhib.dao"/>
+    <context:component-scan base-package="org.shiro.samples.sprhib.security"/>
+    <context:component-scan base-package="org.shiro.samples.sprhib.service"/>
 
-    <!-- Spring AOP auto-proxy creation (required to support Ki annotations) -->
+    <!-- Spring AOP auto-proxy creation (required to support Shiro annotations) -->
     <bean class="org.springframework.aop.framework.autoproxy.DefaultAdvisorAutoProxyCreator"/>
 
 
@@ -44,7 +44,7 @@
          instance.  Change to your application's settings for a real app. -->
     <bean id="dataSource" class="org.springframework.jdbc.datasource.DriverManagerDataSource">
         <property name="driverClassName" value="org.hsqldb.jdbcDriver"/>
-        <property name="url" value="jdbc:hsqldb:mem:ki-spring-hibernate"/>
+        <property name="url" value="jdbc:hsqldb:mem:shiro-spring-hibernate"/>
         <property name="username" value="sa"/>
     </bean>
 
@@ -56,7 +56,7 @@
              DDL is auto-generated based on the *.hbm.xml mapping definitions below. -->
         <property name="schemaUpdate" value="true"/>
         <!-- Scan packages for JPA annotations -->
-        <property name="packagesToScan" value="org.ki.samples.sprhib.model"/>
+        <property name="packagesToScan" value="org.shiro.samples.sprhib.model"/>
         <property name="hibernateProperties">
             <props>
                 <prop key="hibernate.dialect">org.hibernate.dialect.HSQLDialect</prop>
@@ -82,23 +82,23 @@
 
 
     <!-- =========================================================
-         Ki Components
+         Shiro Components
          ========================================================= -->
 
-    <!-- Ki's main business-tier object for web-enabled applications
+    <!-- Shiro's main business-tier object for web-enabled applications
          (use org.kifaultSecurityManager instead when there is no web environment)-->
-    <bean id="securityManager" class="org.apache.ki.web.DefaultWebSecurityManager">
+    <bean id="securityManager" class="org.apache.shiro.web.DefaultWebSecurityManager">
         <!-- Single realm app (realm configured next, below).  If you have multiple realms, use the 'realms'
       property instead. -->
         <property name="realm" ref="sampleRealm"/>
         <!-- Uncomment this next property if you want heterogenous session access or clusterable/distributable
              sessions.  The default value is 'http' which uses the Servlet container's HttpSession as the underlying
              Session implementation.
-        <property name="sessionMode" value="ki"/> -->
+        <property name="sessionMode" value="shiro"/> -->
     </bean>
 
 
     <!-- Post processor that automatically invokes init() and destroy() methods -->
-    <bean id="lifecycleBeanPostProcessor" class="org.apache.ki.spring.LifecycleBeanPostProcessor"/>
+    <bean id="lifecycleBeanPostProcessor" class="org.apache.shiro.spring.LifecycleBeanPostProcessor"/>
 
 </beans>

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/editUser.jsp
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/editUser.jsp?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/editUser.jsp (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/editUser.jsp Thu Jun 18 03:13:34 2009
@@ -21,12 +21,12 @@
 
 <html>
 <head>
-    <title>Apache Ki Spring-Hibernate Sample Application</title>
+    <title>Apache Shiro Spring-Hibernate Sample Application</title>
     <link rel="stylesheet" type="text/css" href="<c:url value="/styles/sample.css"/>"/>
 </head>
 <body>
     <div id="box">
-        <div class="title">Apache Ki Sample App - Edit User</div>
+        <div class="title">Apache Shiro Sample App - Edit User</div>
 
         <div class="content">
             <form:form modelAttribute="editUserCommand">

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/home.jsp
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/home.jsp?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/home.jsp (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/home.jsp Thu Jun 18 03:13:34 2009
@@ -17,17 +17,17 @@
   ~ under the License.
   --%>
 <%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
-<%@ taglib prefix="ki" uri="http://ki.apache.org/tags" %>
+<%@ taglib prefix="shiro" uri="http://shiro.apache.org/tags" %>
 
 <html>
 <head>
-    <title>Apache Ki Spring-Hibernate Sample Application</title>
+    <title>Apache Shiro Spring-Hibernate Sample Application</title>
     <link rel="stylesheet" type="text/css" href="<c:url value="/styles/sample.css"/>"/>
 </head>
 <body>
 
 <div id="bigbox">
-    <div class="title clearfix"><div style="float: left">Apache Ki Sample App - Home</div><div class="info" >Logged in as ${currentUser.username} (<a href="<c:url value="/s/logout"/>">Logout</a>)</div></div>
+    <div class="title clearfix"><div style="float: left">Apache Shiro Sample App - Home</div><div class="info" >Logged in as ${currentUser.username} (<a href="<c:url value="/s/logout"/>">Logout</a>)</div></div>
 
 
     <div class="content">
@@ -40,12 +40,12 @@
         </ul>
 
         <p>
-        <ki:hasPermission name="user:manage">
+        <shiro:hasPermission name="user:manage">
             Since you are logged in as the admin user, you can <a href="<c:url value="/s/manageUsers"/>">manage site users</a>.
-        </ki:hasPermission>
-        <ki:lacksPermission name="user:manage">
+        </shiro:hasPermission>
+        <shiro:lacksPermission name="user:manage">
             Since you are not logged in as the admin user, you can't manage site users.
-        </ki:lacksPermission>
+        </shiro:lacksPermission>
         </p>
     </div>
 

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/login.jsp
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/login.jsp?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/login.jsp (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/login.jsp Thu Jun 18 03:13:34 2009
@@ -21,12 +21,12 @@
 
 <html>
 <head>
-    <title>Apache Ki Spring-Hibernate Sample Application</title>
+    <title>Apache Shiro Spring-Hibernate Sample Application</title>
     <link rel="stylesheet" type="text/css" href="<c:url value="/styles/sample.css"/>"/> 
 </head>
 <body>
     <div id="box">
-        <div class="title">Apache Ki Sample App - Login</div>
+        <div class="title">Apache Shiro Sample App - Login</div>
 
         <div class="content">
             <form:form modelAttribute="loginCommand">

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/manageUsers.jsp
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/manageUsers.jsp?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/manageUsers.jsp (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/manageUsers.jsp Thu Jun 18 03:13:34 2009
@@ -17,17 +17,17 @@
   ~ under the License.
   --%>
 <%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
-<%@ taglib prefix="ki" uri="http://ki.apache.org/tags" %>
+<%@ taglib prefix="shiro" uri="http://shiro.apache.org/tags" %>
 
 <html>
 <head>
-    <title>Apache Ki Spring-Hibernate Sample Application</title>
+    <title>Apache Shiro Spring-Hibernate Sample Application</title>
     <link rel="stylesheet" type="text/css" href="<c:url value="/styles/sample.css"/>"/>
 </head>
 <body>
 
 <div id="bigbox">
-    <div class="title clearfix"><div style="float: left">Apache Ki Sample App - Manage Users</div><div class="info" >Logged in as ${currentUser.username} (<a href="<c:url value="/s/logout"/>">Logout</a>)</div></div>
+    <div class="title clearfix"><div style="float: left">Apache Shiro Sample App - Manage Users</div><div class="info" >Logged in as ${currentUser.username} (<a href="<c:url value="/s/logout"/>">Logout</a>)</div></div>
 
 
     <div class="content">

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/signup.jsp
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/signup.jsp?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/signup.jsp (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/jsp/signup.jsp Thu Jun 18 03:13:34 2009
@@ -21,12 +21,12 @@
 
 <html>
 <head>
-    <title>Apache Ki Spring-Hibernate Sample Application</title>
+    <title>Apache Shiro Spring-Hibernate Sample Application</title>
     <link rel="stylesheet" type="text/css" href="<c:url value="/styles/sample.css"/>"/>
 </head>
 <body>
     <div id="box">
-        <div class="title">Apache Ki Sample App - Signup</div>
+        <div class="title">Apache Shiro Sample App - Signup</div>
 
         <div class="content">
             <form:form modelAttribute="signupCommand">

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/sprhib-servlet.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/sprhib-servlet.xml?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/sprhib-servlet.xml (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/sprhib-servlet.xml Thu Jun 18 03:13:34 2009
@@ -29,11 +29,11 @@
 
     <!-- Enable annotation component scanning and autowiring of web package -->
     <context:annotation-config/>
-    <context:component-scan base-package="org.ki.samples.sprhib.web"/>
+    <context:component-scan base-package="org.shiro.samples.sprhib.web"/>
 
     <!-- Required for security annotations to work in this servlet -->
     <bean class="org.springframework.aop.framework.autoproxy.DefaultAdvisorAutoProxyCreator"/>
-    <bean class="org.apache.ki.spring.security.interceptor.AuthorizationAttributeSourceAdvisor"/>
+    <bean class="org.apache.shiro.spring.security.interceptor.AuthorizationAttributeSourceAdvisor"/>
 
 
     <!-- Enable annotation-based controllers using @Controller annotations -->

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/web.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/web.xml?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/web.xml (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/WEB-INF/web.xml Thu Jun 18 03:13:34 2009
@@ -38,7 +38,7 @@
     -->
     <context-param>
         <param-name>webAppRootKey</param-name>
-        <param-value>ki-spring-hibernate-sample.webapp.root</param-value>
+        <param-value>shiro-spring-hibernate-sample.webapp.root</param-value>
     </context-param>
 
     <!-- ===================================================================
@@ -61,7 +61,7 @@
 
     <filter>
         <filter-name>KiFilter</filter-name>
-        <filter-class>org.apache.ki.spring.SpringKiFilter</filter-class>
+        <filter-class>org.apache.shiro.spring.SpringShiroFilter</filter-class>
         <init-param>
             <param-name>config</param-name>
             <param-value>
@@ -69,16 +69,16 @@
                 # The KiFilter configuration is very powerful and flexible, while still remaining succinct.
                 # Please read the comprehensive example, with full comments and explanations, in the JavaDoc:
                 #
-                # http://ki.apache.org/api/org/apache/ki/web/servlet/KiFilter.html
+                # http://shiro.apache.org/api/org/apache/shiro/web/servlet/KiFilter.html
 
-                # If you'd prefer to not have this configuration in web.xml, you can create a file called ki.ini
-                # in the root of your classpath and Ki will automatically pick it up.
+                # If you'd prefer to not have this configuration in web.xml, you can create a file called shiro.ini
+                # in the root of your classpath and Shiro will automatically pick it up.
 
                 [filters]
                 # Override the authentication filter to pass thru so we can handle login logic in our controller
-                authc = org.apache.ki.web.filter.authc.PassThruAuthenticationFilter
-                ki.loginUrl = /s/login
-                ki.unauthorizedUrl = /unauthorized.jsp
+                authc = org.apache.shiro.web.filter.authc.PassThruAuthenticationFilter
+                shiro.loginUrl = /s/login
+                shiro.unauthorizedUrl = /unauthorized.jsp
                 authc.successUrl = /s/home
 
                 [urls]

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/unauthorized.jsp
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/unauthorized.jsp?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/unauthorized.jsp (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/webapp/unauthorized.jsp Thu Jun 18 03:13:34 2009
@@ -19,7 +19,7 @@
 <%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
 <html>
 <head>
-    <title>Apache Ki Spring-Hibernate Sample Application</title>
+    <title>Apache Shiro Spring-Hibernate Sample Application</title>
     <link rel="stylesheet" type="text/css" href="<c:url value="/styles/sample.css"/>"/>
 </head>
 <body>

Modified: incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/BootstrapDataPopulator.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/BootstrapDataPopulator.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/BootstrapDataPopulator.java (original)
+++ incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/BootstrapDataPopulator.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.samples.spring;
+package org.apache.shiro.samples.spring;
 
 import javax.sql.DataSource;
 
@@ -26,12 +26,12 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.crypto.hash.Sha256Hash;
+import org.apache.shiro.crypto.hash.Sha256Hash;
 
 /**
  * A data populator that creates a set of security tables and test data that can be used by the
- * Ki Spring sample application to demonstrate the use of the {@link org.apache.ki.realm.jdbc.JdbcRealm}
- * The tables created by this class follow the default table and column names that {@link org.apache.ki.realm.jdbc.JdbcRealm} uses.
+ * Shiro Spring sample application to demonstrate the use of the {@link org.apache.shiro.realm.jdbc.JdbcRealm}
+ * The tables created by this class follow the default table and column names that {@link org.apache.shiro.realm.jdbc.JdbcRealm} uses.
  *
  * @author Les Hazlewood
  */

Modified: incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/DefaultSampleManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/DefaultSampleManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/DefaultSampleManager.java (original)
+++ incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/DefaultSampleManager.java Thu Jun 18 03:13:34 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.samples.spring;
+package org.apache.shiro.samples.spring;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.SecurityUtils;
-import org.apache.ki.session.Session;
-import org.apache.ki.subject.Subject;
+import org.apache.shiro.SecurityUtils;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.subject.Subject;
 
 
 /**

Modified: incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/SampleManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/SampleManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/SampleManager.java (original)
+++ incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/SampleManager.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.samples.spring;
+package org.apache.shiro.samples.spring;
 
-import org.apache.ki.authz.annotation.RequiresPermissions;
-import org.apache.ki.authz.annotation.RequiresRoles;
+import org.apache.shiro.authz.annotation.RequiresPermissions;
+import org.apache.shiro.authz.annotation.RequiresRoles;
 
 
 /**

Modified: incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/ui/WebStartDriver.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/ui/WebStartDriver.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/ui/WebStartDriver.java (original)
+++ incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/ui/WebStartDriver.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.samples.spring.ui;
+package org.apache.shiro.samples.spring.ui;
 
 import org.springframework.context.support.ClassPathXmlApplicationContext;
 

Modified: incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/ui/WebStartView.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/ui/WebStartView.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/LoginCommand.java (original)
+++ incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/LoginCommand.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.samples.spring.web;
+package org.apache.shiro.samples.spring.web;
 
 /**
  * Command object that parameters are bound to when logging into the sample

Modified: incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/LoginController.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/LoginController.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/LoginController.java (original)
+++ incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/LoginController.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.samples.spring.web;
+package org.apache.shiro.samples.spring.web;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -25,9 +25,9 @@
 import org.springframework.web.servlet.ModelAndView;
 import org.springframework.web.servlet.mvc.SimpleFormController;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.UsernamePasswordToken;
-import org.apache.ki.mgt.SecurityManager;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.UsernamePasswordToken;
+import org.apache.shiro.mgt.SecurityManager;
 
 /**
  * Spring MVC controller responsible for authenticating the user.
@@ -44,7 +44,7 @@
     /*--------------------------------------------
     |    I N S T A N C E   V A R I A B L E S    |
     ============================================*/
-    private org.apache.ki.mgt.SecurityManager securityManager;
+    private org.apache.shiro.mgt.SecurityManager securityManager;
 
     /*--------------------------------------------
     |         C O N S T R U C T O R S           |

Modified: incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/LogoutController.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/LogoutController.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/LogoutController.java (original)
+++ incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/LogoutController.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.samples.spring.web;
+package org.apache.shiro.samples.spring.web;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -25,12 +25,12 @@
 import org.springframework.web.servlet.ModelAndView;
 import org.springframework.web.servlet.mvc.AbstractController;
 
-import org.apache.ki.SecurityUtils;
-import org.apache.ki.subject.Subject;
+import org.apache.shiro.SecurityUtils;
+import org.apache.shiro.subject.Subject;
 
 /**
  * Controller responsible for logging out the current user by invoking
- * {@link org.apache.ki.subject.Subject#logout()}
+ * {@link org.apache.shiro.subject.Subject#logout()}
  *
  * @author Jeremy Haile
  * @since 0.1

Modified: incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/SessionValueCommand.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/SessionValueCommand.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/SessionValueCommand.java (original)
+++ incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/SessionValueCommand.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.samples.spring.web;
+package org.apache.shiro.samples.spring.web;
 
 /**
  * Command object used to bind parameters when submitting a value to be
--- incubator/shiro/trunk/samples/quickstart/src/main/java/Quickstart.java (original)
+++ incubator/shiro/trunk/samples/quickstart/src/main/java/Quickstart.java Thu Jun 18 03:13:34 2009
@@ -17,12 +17,12 @@
  * under the License.
  */
 
-import org.apache.ki.SecurityUtils;
-import org.apache.ki.authc.*;
-import org.apache.ki.mgt.DefaultSecurityManager;
-import org.apache.ki.realm.text.PropertiesRealm;
-import org.apache.ki.session.Session;
-import org.apache.ki.subject.Subject;
+import org.apache.shiro.SecurityUtils;
+import org.apache.shiro.authc.*;
+import org.apache.shiro.mgt.DefaultSecurityManager;
+import org.apache.shiro.realm.text.PropertiesRealm;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.subject.Subject;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -39,8 +39,8 @@
     public static void main( String[] args ) {
 
         //Most applications would never instantiate a SecurityManager directly - you would instead configure
         //Ki in web.xml or a container (JEE, Spring, etc).
         //But, since this is a quickstart, we just want you to get a feel for how the Ki API looks, so this
         //is sufficient to have a simple working example:
         DefaultSecurityManager securityManager = new DefaultSecurityManager();
         securityManager.setRealm(new PropertiesRealm());
@@ -52,7 +52,7 @@
         SecurityUtils.setSecurityManager( securityManager );
 
 
         //now that a simple Ki environment is set up, let's see what you can do:
 
         //get the currently executing user:
         Subject currentUser = SecurityUtils.getSubject();
@@ -39,8 +39,8 @@
 
         //Most applications would never instantiate a SecurityManager directly - you would instead configure
-        //Ki in web.xml or a container (JEE, Spring, etc).
-        //But, since this is a quickstart, we just want you to get a feel for how the Ki API looks, so this
+        //Shiro in web.xml or a container (JEE, Spring, etc).
+        //But, since this is a quickstart, we just want you to get a feel for how the Shiro API looks, so this
         //is sufficient to have a simple working example:
         DefaultSecurityManager securityManager = new DefaultSecurityManager();
@@ -52,7 +52,7 @@
 
 
-        //now that a simple Ki environment is set up, let's see what you can do:
+        //now that a simple Shiro environment is set up, let's see what you can do:
 
         //get the currently executing user:

Modified: incubator/shiro/trunk/samples/quickstart/src/main/resources/log4j.properties
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/quickstart/src/main/resources/log4j.properties?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/security/SampleRealm.java (original)
+++ incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/security/SampleRealm.java Thu Jun 18 03:13:34 2009
@@ -18,20 +18,20 @@
  */
 package org.jsecurity.samples.sprhib.security;
 
-import org.apache.ki.authc.*;
-import org.apache.ki.authc.credential.Sha256CredentialsMatcher;
-import org.apache.ki.authz.AuthorizationInfo;
-import org.apache.ki.authz.SimpleAuthorizationInfo;
-import org.apache.ki.realm.AuthorizingRealm;
+import org.apache.shiro.authc.*;
+import org.apache.shiro.authc.credential.Sha256CredentialsMatcher;
+import org.apache.shiro.authz.AuthorizationInfo;
+import org.apache.shiro.authz.SimpleAuthorizationInfo;
+import org.apache.shiro.realm.AuthorizingRealm;
 import org.jsecurity.samples.sprhib.dao.UserDAO;
 import org.jsecurity.samples.sprhib.model.Role;
 import org.jsecurity.samples.sprhib.model.User;
-import org.apache.ki.subject.PrincipalCollection;
+import org.apache.shiro.subject.PrincipalCollection;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Component;
 
 /**
  * The Spring/Hibernate sample application's one and only configured Apache Ki Realm.
  *
  * <p>Because a Realm is really just a security-specific DAO, we could have just made Hibernate calls directly
  * in the implementation and named it a 'HibernateRealm' or something similar.</p>
@@ -18,20 +18,20 @@
 
 /**
- * The Spring/Hibernate sample application's one and only configured Apache Ki Realm.
+ * The Spring/Hibernate sample application's one and only configured Apache Shiro Realm.
  *
  * <p>Because a Realm is really just a security-specific DAO, we could have just made Hibernate calls directly

Modified: incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/service/DefaultUserService.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring-hibernate/src/main/java/org/jsecurity/samples/sprhib/service/DefaultUserService.java?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/ui/WebStartView.java (original)
+++ incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/ui/WebStartView.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.samples.spring.ui;
+package org.apache.shiro.samples.spring.ui;
 
 import java.awt.*;
 import java.awt.event.ActionEvent;
@@ -28,14 +28,14 @@
 import org.springframework.beans.factory.InitializingBean;
 import org.springframework.core.io.ClassPathResource;
 
-import org.apache.ki.authz.AuthorizationException;
-import org.apache.ki.samples.spring.DefaultSampleManager;
-import org.apache.ki.samples.spring.SampleManager;
+import org.apache.shiro.authz.AuthorizationException;
+import org.apache.shiro.samples.spring.DefaultSampleManager;
+import org.apache.shiro.samples.spring.SampleManager;
 
 
 /**
  * Simple web start application that helps to demo single sign-on and
  * remoting authorization using Ki.  The injected <tt>SampleManager</tt>
  * is hosted by the Spring sample web application and remotely invoked
  * when the buttons in this view are clicked.
  *
@@ -108,7 +108,7 @@
         methodPanel.add(secureMethod2Button);
         methodPanel.add(secureMethod3Button);
 
-        frame = new JFrame("Apache Ki Sample Application");
+        frame = new JFrame("Apache Shiro Sample Application");
         frame.setSize(500, 200);
 
         Container panel = frame.getContentPane();
@@ -28,14 +28,14 @@
 /**
  * Simple web start application that helps to demo single sign-on and
- * remoting authorization using Ki.  The injected <tt>SampleManager</tt>
+ * remoting authorization using Shiro.  The injected <tt>SampleManager</tt>
  * is hosted by the Spring sample web application and remotely invoked
  * when the buttons in this view are clicked.

Modified: incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/IndexController.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/IndexController.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/IndexController.java (original)
+++ incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/IndexController.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.samples.spring.web;
+package org.apache.shiro.samples.spring.web;
 
 import java.util.HashMap;
 import java.util.Map;
@@ -28,12 +28,12 @@
 import org.springframework.web.servlet.ModelAndView;
 import org.springframework.web.servlet.mvc.SimpleFormController;
 
-import org.apache.ki.SecurityUtils;
-import org.apache.ki.samples.spring.SampleManager;
-import org.apache.ki.subject.Subject;
+import org.apache.shiro.SecurityUtils;
+import org.apache.shiro.samples.spring.SampleManager;
+import org.apache.shiro.subject.Subject;
 
 /**
  * Spring MVC controller responsible for rendering the Ki Spring sample
  * application index page.
  *
  * @author Jeremy Haile
@@ -28,12 +28,12 @@
 
 /**
- * Spring MVC controller responsible for rendering the Ki Spring sample
+ * Spring MVC controller responsible for rendering the Shiro Spring sample
  * application index page.
  *

Modified: incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/JnlpController.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/JnlpController.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/JnlpController.java (original)
+++ incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/JnlpController.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.samples.spring.web;
+package org.apache.shiro.samples.spring.web;
 
 import java.util.HashMap;
 import java.util.Map;
@@ -26,12 +26,12 @@
 import org.springframework.web.servlet.ModelAndView;
 import org.springframework.web.servlet.mvc.AbstractController;
 
-import org.apache.ki.SecurityUtils;
-import org.apache.ki.session.Session;
-import org.apache.ki.subject.Subject;
+import org.apache.shiro.SecurityUtils;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.subject.Subject;
 
 /**
  * Controller used to dynamically build a JNLP file used to launch the Ki
  * Spring WebStart sample application.
  *
  * @author Jeremy Haile
@@ -73,7 +73,7 @@
             session = subject.getSession();
         }
         if (session == null) {
-            String msg = "Expected a non-null Ki session.";
+            String msg = "Expected a non-null Shiro session.";
             throw new IllegalArgumentException(msg);
         }
 
@@ -26,12 +26,12 @@
 
 /**
- * Controller used to dynamically build a JNLP file used to launch the Ki
+ * Controller used to dynamically build a JNLP file used to launch the Shiro
  * Spring WebStart sample application.
  *

Modified: incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/LoginCommand.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/java/org/apache/shiro/samples/spring/web/LoginCommand.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================